def call(body) {
    def pipelineParams= [:]
    body.resolveStrategy = Closure.DELEGATE_FIRST
    body.delegate = pipelineParams
    body()

    pipeline {
        agent any
        
        
        //variables environment
        environment {

                    def shortCommit = sh(returnStdout: true, script: "git log -n 1 --pretty=format:'%h'").trim()
                    def author = sh(returnStdout: true, script: "git show -s --pretty=%an").trim()
                    def url = sh(returnStdout: true, script: 'git config remote.origin.url').trim()
                    def notificationURL = "${url.replace(':', '/').replace('git@', 'https://')}"
        }



        stages {
                            
                            stage('checkout') {
                                steps {
                                    checkout scm
                                }
                            }

                            stage('check python') {
                                steps {
                                    sh "python3 --version"
                                }
                            }


                            stage('Build ') {
                                when {
                                    branch 'master'
                                }
                                steps {
                                    sh """
                                        echo 'build step'
                                        docker build -t  ${pipelineParams.imageName}:${shortCommit} .
                                    """
                                }
                            }


                            stage('Push ') {
                                when {
                                    branch 'master'
                                }
                                steps {
                                    sh """
                                        docker push ${pipelineParams.imageName}:${shortCommit}
                                    """
                                }
                            }
                            //changer le tag de l'image, le remplacer sur le value.yaml
                            stage('GitOps') {
                                when {
                                    branch 'master'
                                }
                                steps {
                                    script {
                                        dir('charts') {
                                            sh "rm -rf ./*"

                                            git( credentialsId: 'GITLAB_CREDENTIALS', url: 'https://gitlab.baamtu.com/diopbe/helm-manifestfiles', branch: 'master' ) 
                                            sh """
                                            git config --global user.email "jenkins@baamtu.com"
                                            git config --global user.name "Jenkins"

                                            yq e -i '.image.tag = "${shortCommit}"'  ${VALUES_FILE}
                                            git commit -am "new build for ${BRANCH_NAME} - commit hash=${shortCommit}"

                                            """
                                            withCredentials([usernamePassword(credentialsId: 'GITLAB_CREDENTIALS', passwordVariable: 'GIT_PASSWORD', usernameVariable: 'GIT_USERNAME')]) {
                                            sh ('git remote set-url origin https://${GIT_USERNAME}:${GIT_PASSWORD}@gitlab.baamtu.com/diopbe/helm-manifestfiles')
                                            sh('git push origin master')
                                
                                        }
                                    }
                                }
                            
                            }


                            stage('Clean ') {
                                    when {
                                        branch 'master'
                                    }
                                    steps {
                                        sh """
                                            echo 'Clean'
                                            docker rmi ${pipelineParams.imageName}:${shortCommit}
                                        """
                                    }
                                } 
 
        }

          // Slack Notifications
        
        
        post {


        }

    }
}